Flags

Struct Flags 

pub struct Flags(pub hb_subset_flags_t);
Flags for SubsetInput.

These flags can be used to instruct which tables the subsetter should touch, and how.

Default flags

assert_eq!(
    *Flags::default()
        .retain_hinting()
        .remap_glyph_indices()
        .retain_subroutines()
        .retain_subroutines()
        .remove_legacy_names()
        .remove_overlap_simple_flag()
        .remove_unrecognized_tables()
        .remove_notdef_outline()
        .remove_glyph_names()
        .recompute_unicode_ranges()
        .retain_layout_closure(),
    Flags::default()
);

Tuple Fields

0: hb_subset_flags_t

Implementations

Source

impl Flags

pub fn remove_hinting(&mut self) -> &mut Self

Instructs subsetter to remove hinting instructions.

pub fn retain_hinting(&mut self) -> &mut Self

Instructs subsetter to retain hinting instructions.

pub fn retain_glyph_indices(&mut self) -> &mut Self

Instructs subsetter to glyph indices.

If a glyph gets dropped, its index will still be retained as an empty glyph.

pub fn remap_glyph_indices(&mut self) -> &mut Self

Instructs subsetter to map old glyph indices to new ones.

pub fn remove_subroutines(&mut self) -> &mut Self

Instructs subsetter to remove subroutines from the CFF glyphs.

This has only effect when subsetting a CFF font.

pub fn retain_subroutines(&mut self) -> &mut Self

Instructs subsetter to retain subroutines for CFF glyphs.

pub fn retain_legacy_names(&mut self) -> &mut Self

Instructs subsetter to keep non-unicode name records.

pub fn remove_legacy_names(&mut self) -> &mut Self

Instructs subsetter to remove non-unicode name records.

pub fn set_overlap_simple_flag(&mut self) -> &mut Self

Instructs subsetter to set OVERLAP_SIMPLE flag for simple glyphs.

This is not required for OpenType, but may affect rendering in some platforms.

pub fn remove_overlap_simple_flag(&mut self) -> &mut Self

Instructs subsetter to not emit OVERLAP_SIMPLE flag.

pub fn retain_unrecognized_tables(&mut self) -> &mut Self

Instructs subsetter to keep unrecognized tables.

The subsetter wil just pass them trough without touching them.

pub fn remove_unrecognized_tables(&mut self) -> &mut Self

Instructs subsetter to remove unrecognized tables.

pub fn retain_notdef_outline(&mut self) -> &mut Self

Instructs subsetter to keep glyph outline for `notdef``.

pub fn remove_notdef_outline(&mut self) -> &mut Self

Instructs subsetter to remove glyph outline for `notdef``.

pub fn retain_glyph_names(&mut self) -> &mut Self

Instructs subsetter to keep glyph name information.

pub fn remove_glyph_names(&mut self) -> &mut Self

Instructs subsetter to remove glyph name information.

pub fn recompute_unicode_ranges(&mut self) -> &mut Self

Instructs subsetter to recompute unicode ranges in OS/2 table.

pub fn retain_unicode_ranges(&mut self) -> &mut Self

Instructs subsetter to keep original unicode ranges in OS/2 table.

pub fn retain_layout_closure(&mut self) -> &mut Self

Instructs subsetter to keep glyphs for all possible combinations of already retained glyphs.

For example, if glyphs corresponding to f and i are retained, then also glyphs corresponding to , and are retained.

pub fn no_layout_closure(&mut self) -> &mut Self

Instructs subsetter to keep only minimum set of glyphs disregarding layout closure.